import { reactive } from 'vue'
import { DataMerger } from './Methods'

/** 默认的系统参数 */
const Sys: SystemParametersType = {
    /** DeBug 开关 */
    debug: false,

    /** 展开搜索表单 */
    IssearchForm: true,
    /** 表单 Label 宽度 */
    labelWidth: 120,

    /** 表格展开行是否开启 */
    expand: true,

    /** 操作菜单宽度 */
    menuWidth: 310,
    /** 操作菜单对齐位置 */
    menuAlign: 'left',

    /** 对话框宽度 */
    modalWidth: 800,
    /** 对话框页脚按钮 */
    editFooterButton: true,

    /** 分页大小 */
    pageSizes: [10, 20, 50, 100],
    /** 分页参数 */
    Pagination: {
        current: 1,
        pageSize: 10,
        total: 0
    },
    /** 分页组件布局，子组件名用逗号分隔 */
    PaginationLayout: '->,total, sizes, prev, pager, next, jumper',

    /** 数据加载完成后是否立即查询 */
    queryAfterMount: false,
    /** 表格的多选框是否开启 */
    openMultipleSelection: false,
    /** 点击 model 关闭对话框 */
    destroyOnClosModal: true,

    /** api 接口名称 */
    apiName: {
        query: 'query',
        add: 'add',
        edit: 'edit',
        delete: 'delete',
        deleteFlag: 'deleteFlag',
        remove: 'remove'
    },
    /** 页面节点权限名称 */
    permission: {
        add: 'add',
        edit: 'edit',
        delete: 'delete',
        deleteFlag: 'deleteFlag',
        remove: 'remove'
    },
    /** 拥有的权限 */
    permissions: ['add', 'edit', 'delete', 'deleteFlag', 'remove']
}

/** 系统参数 */
let SysParams: any = reactive({})

/** DeBug */
function debug(...params: any) {
    if (SysParams.debug) {
        console.info('%c【DeBug】', 'color:red', ...params)
    }
}
/** 初始化系统参数 */
const InitSys = (opt: any) => {
    SysParams = DataMerger(Sys, opt)
}

// 执行初始化函数
;(() => {
    InitSys({})
})()

export { InitSys, SysParams, debug }
